Overview
===========


:Title: DREAM 8 - The Whole-Cell Parameter Estimation DREAM Challenge
:Nickname: D8C3
:Summary: Participants were provided with a whole cell model of Mycoplasma genitalium and tasked with estimating the model parameters for specific biological processes from simulated data.
:Synapse page: https://www.synapse.org/#!Synapse:syn1876068

This challenge being complex, an external github repository exists on its own : https://github.com/jonrkarr
